@@ -1,5 +1,6 @@
 /* Procman - main window
  * Copyright (C) 2001 Kevin Vandersloot
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -785,7 +786,7 @@ update_sensitivity(ProcData *data)
     GtkAction *action;
 
     processes_sensitivity = (data->config.current_tab == PROCMAN_TAB_PROCESSES);
-    selected_sensitivity = (processes_sensitivity && data->selected_process != NULL);
+    selected_sensitivity = (processes_sensitivity && data->selection && gtk_tree_selection_count_selected_rows (data->selection) > 0);
 
     if(data->endprocessbutton) {
         /* avoid error on startup if endprocessbutton
