@@ -1,5 +1,6 @@
 /* Procman
  * Copyright (C) 2001 Kevin Vandersloot
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -64,16 +65,6 @@ static const unsigned MIN_UPDATE_INTERVAL =   1 * 1000;
 static const unsigned MAX_UPDATE_INTERVAL = 100 * 1000;
 
 
-namespace procman
-{
-    extern const std::string SHOW_SYSTEM_TAB_CMD;
-    extern const std::string SHOW_PROCESSES_TAB_CMD;
-    extern const std::string SHOW_RESOURCES_TAB_CMD;
-    extern const std::string SHOW_FILE_SYSTEMS_TAB_CMD;
-}
-
-
-
 enum ProcmanTab
 {
     PROCMAN_TAB_SYSINFO,
@@ -136,8 +127,10 @@ MutableProcInfo()
     gulong memwritable;
     gulong mem;
 
+#ifdef HAVE_WNCK
     // wnck gives an unsigned long
     gulong memxserver;
+#endif
 
     gulong start_time;
     guint64 cpu_time;
@@ -250,6 +243,8 @@ struct ProcData
     guint64 cpu_total_time;
     guint64 cpu_total_time_last;
 
+    gboolean terminating;
+
 private:
     ProcData();
     /* undefined */ ProcData(const ProcData &);
